"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.help = exports.cliOptionsTypes = exports.rcOptionsTypes = exports.commandNames = void 0;
const path_1 = __importDefault(require("path"));
const error_1 = require("@pnpm/error");
const graceful_fs_1 = __importDefault(require("@pnpm/graceful-fs"));
const store_path_1 = require("@pnpm/store-path");
const render_help_1 = __importDefault(require("render-help"));
const INTEGRITY_REGEX = /^([^-]+)-([A-Za-z0-9+/=]+)$/;
exports.commandNames = ['cat-file'];
exports.rcOptionsTypes = cliOptionsTypes;
function cliOptionsTypes() {
    return {};
}
exports.cliOptionsTypes = cliOptionsTypes;
function help() {
    return (0, render_help_1.default)({
        description: 'Prints the contents of a file based on the hash value stored in the index file.',
        descriptionLists: [],
        usages: ['pnpm cat-file <hash>'],
    });
}
exports.help = help;
async function handler(opts, params) {
    if (!params || params.length === 0) {
        throw new error_1.PnpmError('MISSING_HASH', 'Missing file hash', {
            hint: help(),
        });
    }
    const [, , integrityHash] = params[0].match(INTEGRITY_REGEX);
    const toHex = Buffer.from(integrityHash, 'base64').toString('hex');
    const storeDir = await (0, store_path_1.getStorePath)({
        pkgRoot: process.cwd(),
        storePath: opts.storeDir,
        pnpmHomeDir: opts.pnpmHomeDir,
    });
    const cafsDir = path_1.default.join(storeDir, 'files');
    const filePath = path_1.default.resolve(cafsDir, toHex.slice(0, 2), toHex.slice(2));
    try {
        return graceful_fs_1.default.readFileSync(filePath, 'utf8');
    }
    catch (err) { // eslint-disable-line
        if (err.code === 'ENOENT') {
            throw new error_1.PnpmError('INVALID_HASH', 'Corresponding hash file not found');
        }
        throw err;
    }
}
exports.handler = handler;
//# sourceMappingURL=catFile.js.map